From 0e44acbb2fec928a1606dc60f427a148fff405c9 Mon Sep 17 00:00:00 2001
From: Mohamed Ragab <moragab@gmail.com>
Date: Wed, 02 May 2012 11:15:01 -0400
Subject: [PATCH] Added a script to facilitate setting the proxy host and port and no proxy hosts, and then it concatenates all the java system properties for setting the java proxy configurations and puts the resulting string in an environment variable JAVA_PROXY_CONFIG, modified the scirpts gitblit, gitblit-ubuntu, and gitblit-centos to source the java-proxy-config.sh script and then include the resulting java proxy configuration in the java command
---
src/com/gitblit/utils/HttpUtils.java | 5 +++--
1 files changed, 3 insertions(+), 2 deletions(-)
diff --git a/src/com/gitblit/utils/HttpUtils.java b/src/com/gitblit/utils/HttpUtils.java
index 6f0bede..079d1a6 100644
--- a/src/com/gitblit/utils/HttpUtils.java
+++ b/src/com/gitblit/utils/HttpUtils.java
@@ -26,12 +26,12 @@
public class HttpUtils {
/**
* Returns the host URL based on the request.
*
* @param request
* @return the host url
*/
- public static String getHostURL(HttpServletRequest request) {
+ public static String getGitblitURL(HttpServletRequest request) {
StringBuilder sb = new StringBuilder();
sb.append(request.getScheme());
sb.append("://");
@@ -40,6 +40,7 @@
|| (request.getScheme().equals("https") && request.getServerPort() != 443)) {
sb.append(":" + request.getServerPort());
}
+ sb.append(request.getContextPath());
return sb.toString();
}
}
@@ -26,12 +26,12 @@
public class HttpUtils {
/**
- * Returns the host URL based on the request.
+ * Returns the Gitblit URL based on the request.
*
* @param request
--
Gitblit v1.9.1